==> haskell-xml-types-0.3.6-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-types
version: 0.3.6
id: xml-types-0.3.6-FIC5nMiBHCNLIWIJ5UGfdS
key: xml-types-0.3.6-FIC5nMiBHCNLIWIJ5UGfdS
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-xml/
synopsis: Basic types for representing XML
category: Text, XML
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.XML.Types
abi: da7e8f91da1192ced970daf59e4d54ae
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xml-types-0.3.6
hs-libraries: HSxml-types-0.3.6-FIC5nMiBHCNLIWIJ5UGfdS
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
haddock-interfaces: /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html: /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-types-0.3.6-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-types
version: 0.3.6
id: xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
key: xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-xml/
synopsis: Basic types for representing XML
category: Text, XML
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.XML.Types
abi: 66a00e6b1ab0a96693d6da0f27af76bf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xml-types-0.3.6
hs-libraries: HSxml-types-0.3.6-8U94ZZax169GYLVDpT1mig
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
haddock-interfaces: /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html: /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
